#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__K__1___TwoPRep_S__0__F__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+606)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+609)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+618)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+621)*1+lsi)*1]), &(stack[((hsi*3+618)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+627)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+630)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]), &(stack[((hsi*3+627)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+636)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*6+630)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*6+621)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*3+618)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+656)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*10+636)*1+lsi)*1]), &(stack[((hsi*6+621)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+609)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+671)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(stack[((hsi*3+618)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+677)*1+lsi)*1]), &(stack[((hsi*6+671)*1+lsi)*1]), &(stack[((hsi*6+621)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(stack[((hsi*3+618)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+687)*1+lsi)*1]), &(stack[((hsi*10+677)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*6+671)*1+lsi)*1]), &(stack[((hsi*6+621)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+618)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+621)*1+lsi)*1]), &(stack[((hsi*3+627)*1+lsi)*1]), &(stack[((hsi*3+618)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+702)*1+lsi)*1]), &(stack[((hsi*6+630)*1+lsi)*1]), &(stack[((hsi*6+621)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]), &(stack[((hsi*3+627)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+712)*1+lsi)*1]), &(stack[((hsi*10+636)*1+lsi)*1]), &(stack[((hsi*10+702)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*6+630)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+727)*1+lsi)*1]), &(stack[((hsi*15+656)*1+lsi)*1]), &(stack[((hsi*15+712)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*10+636)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+748)*1+lsi)*1]), &(stack[((hsi*15+687)*1+lsi)*1]), &(stack[((hsi*15+656)*1+lsi)*1]), &(stack[((hsi*10+677)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+769)*1+lsi)*1]), &(stack[((hsi*21+748)*1+lsi)*1]), &(stack[((hsi*21+727)*1+lsi)*1]), &(stack[((hsi*15+687)*1+lsi)*1]), &(stack[((hsi*15+656)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+606)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*3+618)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*6+621)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*3+627)*1+lsi)*1]), &(stack[((hsi*3+618)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+797)*1+lsi)*1]), &(stack[((hsi*10+702)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*6+630)*1+lsi)*1]), &(stack[((hsi*6+621)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+812)*1+lsi)*1]), &(stack[((hsi*15+712)*1+lsi)*1]), &(stack[((hsi*15+797)*1+lsi)*1]), &(stack[((hsi*10+636)*1+lsi)*1]), &(stack[((hsi*10+702)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+833)*1+lsi)*1]), &(stack[((hsi*21+727)*1+lsi)*1]), &(stack[((hsi*21+812)*1+lsi)*1]), &(stack[((hsi*15+656)*1+lsi)*1]), &(stack[((hsi*15+712)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+861)*1+lsi)*1]), &(stack[((hsi*28+769)*1+lsi)*1]), &(stack[((hsi*28+833)*1+lsi)*1]), &(stack[((hsi*21+748)*1+lsi)*1]), &(stack[((hsi*21+727)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+627)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+630)*1+lsi)*1]), &(stack[((hsi*3+627)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+636)*1+lsi)*1]), &(stack[((hsi*6+630)*1+lsi)*1]), &(stack[((hsi*6+671)*1+lsi)*1]), &(stack[((hsi*3+627)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+656)*1+lsi)*1]), &(stack[((hsi*10+636)*1+lsi)*1]), &(stack[((hsi*10+677)*1+lsi)*1]), &(stack[((hsi*6+630)*1+lsi)*1]), &(stack[((hsi*6+671)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+897)*1+lsi)*1]), &(stack[((hsi*15+656)*1+lsi)*1]), &(stack[((hsi*15+687)*1+lsi)*1]), &(stack[((hsi*10+636)*1+lsi)*1]), &(stack[((hsi*10+677)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+918)*1+lsi)*1]), &(stack[((hsi*21+897)*1+lsi)*1]), &(stack[((hsi*21+748)*1+lsi)*1]), &(stack[((hsi*15+656)*1+lsi)*1]), &(stack[((hsi*15+687)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+656)*1+lsi)*1]), &(stack[((hsi*28+918)*1+lsi)*1]), &(stack[((hsi*28+769)*1+lsi)*1]), &(stack[((hsi*21+897)*1+lsi)*1]), &(stack[((hsi*21+748)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+946)*1+lsi)*1]), &(stack[((hsi*36+656)*1+lsi)*1]), &(stack[((hsi*36+861)*1+lsi)*1]), &(stack[((hsi*28+769)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+0)*1+lsi)*1]),&(stack[((hsi*108+946)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+609)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+748)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+692)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*6+748)*1+lsi)*1]), &(stack[((hsi*3+618)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+754)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*10+692)*1+lsi)*1]), &(stack[((hsi*6+621)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+897)*1+lsi)*1]), &(stack[((hsi*15+797)*1+lsi)*1]), &(stack[((hsi*15+754)*1+lsi)*1]), &(stack[((hsi*10+702)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+618)*1+lsi)*1]), &(stack[((hsi*21+812)*1+lsi)*1]), &(stack[((hsi*21+897)*1+lsi)*1]), &(stack[((hsi*15+712)*1+lsi)*1]), &(stack[((hsi*15+797)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1054)*1+lsi)*1]), &(stack[((hsi*28+833)*1+lsi)*1]), &(stack[((hsi*28+618)*1+lsi)*1]), &(stack[((hsi*21+727)*1+lsi)*1]), &(stack[((hsi*21+812)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+702)*1+lsi)*1]), &(stack[((hsi*36+861)*1+lsi)*1]), &(stack[((hsi*36+1054)*1+lsi)*1]), &(stack[((hsi*28+769)*1+lsi)*1]), &(stack[((hsi*28+833)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1090)*1+lsi)*1]), &(stack[((hsi*36+656)*1+lsi)*1]), &(stack[((hsi*36+861)*1+lsi)*1]), &(stack[((hsi*28+918)*1+lsi)*1]), &(stack[((hsi*28+769)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1135)*1+lsi)*1]), &(stack[((hsi*45+1090)*1+lsi)*1]), &(stack[((hsi*45+702)*1+lsi)*1]), &(stack[((hsi*36+861)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+108)*1+lsi)*1]),&(stack[((hsi*135+1135)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+769)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+918)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(stack[((hsi*3+769)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+772)*1+lsi)*1]), &(stack[((hsi*6+748)*1+lsi)*1]), &(stack[((hsi*6+918)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+782)*1+lsi)*1]), &(stack[((hsi*10+692)*1+lsi)*1]), &(stack[((hsi*10+772)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*6+748)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+924)*1+lsi)*1]), &(stack[((hsi*15+754)*1+lsi)*1]), &(stack[((hsi*15+782)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*10+692)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1270)*1+lsi)*1]), &(stack[((hsi*21+897)*1+lsi)*1]), &(stack[((hsi*21+924)*1+lsi)*1]), &(stack[((hsi*15+797)*1+lsi)*1]), &(stack[((hsi*15+754)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1298)*1+lsi)*1]), &(stack[((hsi*28+618)*1+lsi)*1]), &(stack[((hsi*28+1270)*1+lsi)*1]), &(stack[((hsi*21+812)*1+lsi)*1]), &(stack[((hsi*21+897)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1334)*1+lsi)*1]), &(stack[((hsi*36+1054)*1+lsi)*1]), &(stack[((hsi*36+1298)*1+lsi)*1]), &(stack[((hsi*28+833)*1+lsi)*1]), &(stack[((hsi*28+618)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+797)*1+lsi)*1]), &(stack[((hsi*45+702)*1+lsi)*1]), &(stack[((hsi*45+1334)*1+lsi)*1]), &(stack[((hsi*36+861)*1+lsi)*1]), &(stack[((hsi*36+1054)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1379)*1+lsi)*1]), &(stack[((hsi*45+1090)*1+lsi)*1]), &(stack[((hsi*45+702)*1+lsi)*1]), &(stack[((hsi*36+656)*1+lsi)*1]), &(stack[((hsi*36+861)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+1434)*1+lsi)*1]), &(stack[((hsi*55+1379)*1+lsi)*1]), &(stack[((hsi*55+797)*1+lsi)*1]), &(stack[((hsi*45+702)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+243)*1+lsi)*1]),&(stack[((hsi*165+1434)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+606)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*3+769)*1+lsi)*1]), &(stack[((hsi*3+606)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*6+918)*1+lsi)*1]), &(stack[((hsi*6+612)*1+lsi)*1]), &(stack[((hsi*3+609)*1+lsi)*1]), &(stack[((hsi*3+769)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+852)*1+lsi)*1]), &(stack[((hsi*10+772)*1+lsi)*1]), &(stack[((hsi*10+646)*1+lsi)*1]), &(stack[((hsi*6+748)*1+lsi)*1]), &(stack[((hsi*6+918)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+646)*1+lsi)*1]), &(stack[((hsi*15+782)*1+lsi)*1]), &(stack[((hsi*15+852)*1+lsi)*1]), &(stack[((hsi*10+692)*1+lsi)*1]), &(stack[((hsi*10+772)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+852)*1+lsi)*1]), &(stack[((hsi*21+924)*1+lsi)*1]), &(stack[((hsi*21+646)*1+lsi)*1]), &(stack[((hsi*15+754)*1+lsi)*1]), &(stack[((hsi*15+782)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+646)*1+lsi)*1]), &(stack[((hsi*28+1270)*1+lsi)*1]), &(stack[((hsi*28+852)*1+lsi)*1]), &(stack[((hsi*21+897)*1+lsi)*1]), &(stack[((hsi*21+924)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+852)*1+lsi)*1]), &(stack[((hsi*36+1298)*1+lsi)*1]), &(stack[((hsi*36+646)*1+lsi)*1]), &(stack[((hsi*28+618)*1+lsi)*1]), &(stack[((hsi*28+1270)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+606)*1+lsi)*1]), &(stack[((hsi*45+1334)*1+lsi)*1]), &(stack[((hsi*45+852)*1+lsi)*1]), &(stack[((hsi*36+1054)*1+lsi)*1]), &(stack[((hsi*36+1298)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+852)*1+lsi)*1]), &(stack[((hsi*55+797)*1+lsi)*1]), &(stack[((hsi*55+606)*1+lsi)*1]), &(stack[((hsi*45+702)*1+lsi)*1]), &(stack[((hsi*45+1334)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1270)*1+lsi)*1]), &(stack[((hsi*55+1379)*1+lsi)*1]), &(stack[((hsi*55+797)*1+lsi)*1]), &(stack[((hsi*45+1090)*1+lsi)*1]), &(stack[((hsi*45+702)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+1599)*1+lsi)*1]), &(stack[((hsi*66+1270)*1+lsi)*1]), &(stack[((hsi*66+852)*1+lsi)*1]), &(stack[((hsi*55+797)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+408)*1+lsi)*1]),&(stack[((hsi*198+1599)*1+lsi)*1]),198);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 606 */
}

#ifdef __cplusplus
};
#endif
